@@ -272,7 +272,7 @@ class GraphManager(WorkFlowManager):
             if job_can_run:
                 try:
                     jobid = self.run_job(job, status["is_retry"])
-                except:
+                except Exception:
                     self._release_resources(job)
                     raise
                 self.__pending_jobs.pop(job)
@@ -302,7 +302,7 @@ class GraphManager(WorkFlowManager):
             if job_can_run:
                 try:
                     jobid = self.run_job(job, status["is_retry"])
-                except:
+                except Exception:
                     self._release_resources(job)
                     raise
                 self.__pending_jobs.pop(job)
@@ -322,6 +322,22 @@ class GraphManager(WorkFlowManager):
             )
         )
 
+    def get_running_jobid(self, job):
+        return self.__running_jobs.get(job)
+
+    def handle_retry(self, job, outcome):
+        jobconf = self.get_job(job)
+        retries = jobconf.get("retries", 0)
+        if retries > 0:
+            self._add_pending_job(job, is_retry=True)
+            jobconf["retries"] -= 1
+            logger.warning(
+                "Will retry job %s (outcome: %s, number of retries left: %s)", job, outcome, jobconf["retries"],
+            )
+            return True
+        logger.warning("No more retries for failed job %s (outcome: %s)", job, outcome)
+        return False
+
     def check_running_jobs(self):
         for job, jobid in list(self.__running_jobs.items()):
             outcome = self.is_finished(jobid)
@@ -334,17 +350,7 @@ class GraphManager(WorkFlowManager):
                         conf["wait_for"].remove(job)
                 for nextjob in self._get_next_jobs(job, outcome):
                     if nextjob == "retry":
-                        jobconf = self.get_job(job)
-                        retries = jobconf.get("retries", 0)
-                        if retries > 0:
-                            self._add_pending_job(job, is_retry=True)
-                            jobconf["retries"] -= 1
-                            logger.warning(
-                                "Will retry job %s (outcome: %s, number of retries left: %s)",
-                                job,
-                                outcome,
-                                jobconf["retries"],
-                            )
+                        self.handle_retry(job, outcome)
                     elif nextjob in self.__pending_jobs:
                         logger.error("Job %s already pending", nextjob)
                     else:
